@@ -227,14 +227,14 @@ repository of the
 
 """
 from abc import abstractmethod, ABC
-from typing import Any, Dict, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union
 
 from ae.inspector import stack_vars                                                         # type: ignore
 from ae.i18n import default_language, get_f_string, translation                             # type: ignore
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.16'
+__version__ = '0.1.17'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -394,38 +394,24 @@ class HelpAppBase(MainAppBase, ABC):
             super().change_app_state(state_name, state_value, send_event=send_event)
             self.help_app_state_display(help_vars, changed=True)
 
-    # noinspection PyIncorrectDocstring
-    def change_flow(self, new_flow_id: str, popups_to_close: Sequence = (), **event_kwargs) -> bool:
+    def change_flow(self, new_flow_id: str, **event_kwargs) -> bool:
         """ change/switch flow id - overriding :meth:`~ae.gui_app.MainAppBase.change_flow`.
 
         More detailed documentation of the parameters you find in the overwritten method
         :meth:`~ae.gui_app.MainAppBase.change_app_state`.
 
-        :param event_kwargs:    optional args to pass additional data or info onto and from the event handler
-                                and to the help text renderer.
-
-                                passed to the help text renderer:
-
-                                * `count`: optional number used for to render a pluralized help text
-                                  for this flow change.
-
-        :return:                True if flow changed and got confirmed by a declared custom event handler
-                                (either event method or Popup class) of the app
-                                AND if the help mode is *not* active or the calling widget is selected
-                                in active help mode, else False.
-                                Some flow actions are handled internally independent from the
-                                return value of a found/declared custom event handler, like e.g. `'enter'` or `'leave'`
-                                will always extend/reduce the flow path and the action `'focus'` will give the
-                                indexed widget the input focus (these exceptions are configurable via
-                                the list :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION`).
+        This method returns True if flow changed and got confirmed by a declared custom event handler
+        (either event method or Popup class) of the app
+        AND if the help mode is *not* active or the calling widget is selected
+        in active help mode, else False.
         """
         count = event_kwargs.pop('count', None)
-        help_vars = dict(new_flow_id=new_flow_id, popups_to_close=popups_to_close, event_kwargs=event_kwargs)
+        help_vars = dict(new_flow_id=new_flow_id, event_kwargs=event_kwargs)
         if count is not None:
             help_vars['count'] = count
 
         if not self.help_flow_display(help_vars):
-            if super().change_flow(new_flow_id, popups_to_close=popups_to_close, **event_kwargs):
+            if super().change_flow(new_flow_id, **event_kwargs):
                 self.help_flow_display(help_vars, changed=True)
                 return True
         return False
